==> 0.0.1.tar.gz: lib/web_layer/javascript_layer.dart <==
@JS()
library web_ble_layer;

import 'dart:html';
import 'dart:js';

import 'package:ble_connectivity/ble_connectivity.dart';
import 'package:ble_connectivity/model/fhp_ble_device.dart';
import 'package:ble_connectivity/web_layer/ble_connectivity_web.dart';
import 'package:flutter/services.dart';
import 'package:js/js.dart';
import 'package:js/js_util.dart';

/// Call javascript
@JS('tryConnect')
external String tryConnectJS(
    dynamic filterName, dynamic scanDuration, dynamic characteristics);
@JS('readSensorCharacteristics')
external String readSensorCharacteristicsJS(
    dynamic deviceName, dynamic characteristics);
@JS('disconnectSensor')
external String disconnectSensorJS(dynamic deviceName);
@JS('getCurrentDeviceValue')
external String onCurrentDeviceValueJS(
    dynamic deviceName, dynamic service, dynamic characteristic);

/// Call from javascript
Future setProperties() async {
  setProperty(window, 'callDartFunc', allowInterop(dartFunc));
  setProperty(window, 'DartOnSensorEvent', allowInterop(onSensorEvent));
  setProperty(window, 'DartOnSensorConnected', allowInterop(onSensorConnected));
  setProperty(
      window, 'DartOnSensorDisconnected', allowInterop(onSensorDisconnected));
  setProperty(window, 'DartStopScan', allowInterop(stopScan));
}

dartFunc() {
  print('gotcha');
}

onSensorEvent(String deviceName, String uuid, dynamic event) {
  //print('onSensorEvent $uuid -> $event');
  (BleConnectivity.instance as BleConnectivityWeb)
      .methodStreamController
      .add(MethodCall('onSensorEvent', [deviceName, uuid, event]));
}

onSensorConnected(dynamic event) {
  print('onSensorConnected $event');

  BleConnectivity.instance.connectWithSensor(
      FhpBleDevice(
        connectionStatus: BleDeviceState.connected,
        rssi: -1,
        name: event,
      ),
      null);
}

onSensorDisconnected(dynamic event) {
  print('onSensorDisconnected from the js $event');
//TODO
  //BleConnectivity.instance.disconnectWithSensor(device)
}

stopScan() {
  BleConnectivity.instance.stopScan();
}

==> 0.0.2.tar.gz: lib/web_layer/javascript_layer.dart <==
@JS()
library web_ble_layer;

import 'dart:html';
import 'dart:js';

import 'package:ble_connectivity/ble_connectivity_target_platform.dart';
import 'package:ble_connectivity/model/fhp_ble_device.dart';
import 'package:ble_connectivity/web_layer/ble_connectivity_web.dart';
import 'package:flutter/services.dart';
import 'package:js/js.dart';
import 'package:js/js_util.dart';

/// Call javascript
@JS('tryConnect')
external String tryConnectJS(
    dynamic filterName, dynamic scanDuration, dynamic characteristics);
@JS('readSensorCharacteristics')
external String readSensorCharacteristicsJS(
    dynamic deviceName, dynamic characteristics);
@JS('disconnectSensor')
external String disconnectSensorJS(dynamic deviceName);
@JS('getCurrentDeviceValue')
external String onCurrentDeviceValueJS(
    dynamic deviceName, dynamic service, dynamic characteristic);

/// Call from javascript
Future setProperties() async {
  setProperty(window, 'callDartFunc', allowInterop(dartFunc));
  setProperty(window, 'DartOnSensorEvent', allowInterop(onSensorEvent));
  setProperty(window, 'DartOnSensorConnected', allowInterop(onSensorConnected));
  setProperty(
      window, 'DartOnSensorDisconnected', allowInterop(onSensorDisconnected));
  setProperty(window, 'DartStopScan', allowInterop(stopScan));
}

dartFunc() {
  print('gotcha');
}

onSensorEvent(String deviceName, String uuid, dynamic event) {
  //print('onSensorEvent $uuid -> $event');
  (BleConnectivityTargetPlatform.instance as BleConnectivityWeb)
      .methodStreamController
      .add(MethodCall('onSensorEvent', [deviceName, uuid, event]));
}

onSensorConnected(dynamic event) {
  print('onSensorConnected $event');

  BleConnectivityTargetPlatform.instance.connectWithSensor(
      FhpBleDevice(
        connectionStatus: BleDeviceState.connected,
        rssi: -1,
        name: event,
      ),
      null);
}

onSensorDisconnected(dynamic event) {
  print('onSensorDisconnected from the js $event');
//TODO
  //BleConnectivity.instance.disconnectWithSensor(device)
}

stopScan() {
  BleConnectivityTargetPlatform.instance.stopScan();
}
